@@ -210,7 +210,7 @@ def compute_baum_welch(spikes, dt, A, B, alpha, beta):
     return gamma, epsilons
 
 
-@njit
+#@njit
 def baum_welch(trial_dat, dt, PI, A, B):
     alpha, norms = forward(trial_dat, dt, PI, A, B)
     beta = backward(trial_dat, dt, A, B, norms)
@@ -693,7 +693,11 @@ def fit_hmm_mp(rec_dir, params, h5_file=None, constraint_func=None):
 
 def load_hmm_from_hdf5(h5_file, hmm_id):
     hmm_id = int(hmm_id)
-    existing_hmm = hmmIO.read_hmm_from_hdf5(h5_file, hmm_id)
+    try:
+        existing_hmm = hmmIO.read_hmm_from_hdf5(h5_file, hmm_id)
+    except:
+        existing_hmm = None
+
     if existing_hmm is None:
         return None, None, None
 
@@ -1182,7 +1186,7 @@ class HmmHandler(object):
     def get_data_overview(self):
         return hmmIO.get_hmm_overview_from_hdf5(self.h5_file)
 
-    def run(self, parallel=True, overwrite=False, constraint_func=None):
+    def run(self, parallel=True, overwrite=False, constraint_func=None, n_cpu=None):
         h5_file = self.h5_file
         rec_dir = self.root_dir
         if overwrite:
@@ -1194,10 +1198,15 @@ class HmmHandler(object):
             return
 
         print('Running fittings')
-        if parallel:
-            n_cpu = np.min((cpu_count()-1, len(fit_params)))
-        else:
+        max_cpu = cpu_count()
+        if parallel and n_cpu is None:
+            n_cpu = int(np.min((cpu_count()-1, len(fit_params))))
+        elif not parallel:
             n_cpu = 1
+        else:
+            n_cpu = int(np.min((n_cpu, len(fit_params))))
+
+        assert (1 <= n_cpu <= max_cpu), f'n_cpu must be a valid integer 1 <= n_cpu <= {max_cpu}'
 
         results = Parallel(n_jobs=n_cpu, verbose=100)(delayed(fit_hmm_mp)
                                                      (rec_dir, p, h5_file,
